# EDTravelCompanion


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install EDTravelCompanion in Development mode

Note that the project is *EDTravelCompanion* while the library is
*edcompanion*

``` sh
# make sure EDTravelCompanion package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to EDTravelCompanion
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/fenke/EDTravelCompanion):

``` sh
$ pip install git+https://github.com/fenke/EDTravelCompanion.git
```

or from [pypi](https://pypi.org/project/EDTravelCompanion/)

``` sh
$ pip install edcompanion
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/fenke/EDTravelCompanion)’s
[pages](https://fenke.github.io/EDTravelCompanion/). Additionally you
can find package manager specific guidelines on
[conda](https://anaconda.org/fenke/EDTravelCompanion) and
[pypi](https://pypi.org/project/EDTravelCompanion/) respectively.

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
